@@ -12,26 +12,27 @@
 
 #include "playground.h"
 
-#include <klocale.h>
-#include <kstandarddirs.h>
+#include <KLocalizedString>
+#include <kconfig.h>
 #include <kconfiggroup.h>
-#include <kdebug.h>
+#include <qdebug.h>
 
+#include <QAction>
 #include <QCursor>
 #include <QDataStream>
+#include <QDir>
 #include <QDomDocument>
 #include <QFile>
+#include <QFileInfo>
 #include <QGraphicsSvgItem>
 #include <QMouseEvent>
 #include <QPainter>
 #include <QPrinter>
-#include <QFileInfo>
+#include <QStandardPaths>
 
 #include <kstandardaction.h>
 #include <kactioncollection.h>
 #include <kstandardshortcut.h>
-#include <kicon.h>
-#include <QAction>
 
 #include "action.h"
 #include "toplevel.h"
@@ -121,14 +122,14 @@ QPixmap PlayGround::getPicture()
 
 void PlayGround::connectRedoAction(QAction *action)
 {
-  connect(action, SIGNAL(triggered()), &m_undoGroup, SLOT(redo()));
-  connect(&m_undoGroup, SIGNAL(canRedoChanged(bool)), action, SLOT(setEnabled(bool)));
+  connect(action, &QAction::triggered, &m_undoGroup, &QUndoGroup::redo);
+  connect(&m_undoGroup, &QUndoGroup::canRedoChanged, action, &QAction::setEnabled);
 }
 
 void PlayGround::connectUndoAction(QAction *action)
 {
-  connect(action, SIGNAL(triggered()), &m_undoGroup, SLOT(undo()));
-  connect(&m_undoGroup, SIGNAL(canUndoChanged(bool)), action, SLOT(setEnabled(bool)));
+  connect(action, &QAction::triggered, &m_undoGroup, &QUndoGroup::undo);
+  connect(&m_undoGroup, &QUndoGroup::canUndoChanged, action, &QAction::setEnabled);
 }
 
 // Mouse pressed event
@@ -235,7 +236,7 @@ QPointF PlayGround::clipPos(const QPointF &p, ToDraw *item) const
 
 QRectF PlayGround::backgroundRect() const
 {
-  return m_SvgRenderer.boundsOnElement(QLatin1String( "background" ));
+  return m_SvgRenderer.boundsOnElement(QStringLiteral( "background" ));
 }
 
 void PlayGround::placeDraggedItem(const QPoint &pos)
@@ -252,7 +253,7 @@ void PlayGround::placeDraggedItem(const QPoint &pos)
   }
   else
   {
-    undoStack()->push(new ActionRemove(m_dragItem, scene()));
+    undoStack()->push(new ActionRemove(m_dragItem, m_itemDraggedPos, scene()));
   }
 
   setCursor(QCursor());
@@ -315,7 +316,16 @@ bool PlayGround::isAspectRatioLocked() const
 // Register the various playgrounds
 void PlayGround::registerPlayGrounds()
 {
-  const QStringList list = KGlobal::dirs()->findAllResources("appdata", QLatin1String( "pics/*.theme" ));
+  QSet<QString> list;
+  const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("pics"), QStandardPaths::LocateDirectory);
+  Q_FOREACH (const QString &dir, dirs)
+  {
+    const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.theme"));
+    Q_FOREACH (const QString &file, fileNames)
+    {
+        list << dir + '/' + file;
+    }
+  }
 
   foreach(const QString &theme, list)
   {
@@ -325,10 +335,10 @@ void PlayGround::registerPlayGrounds()
       QDomDocument layoutDocument;
       if (layoutDocument.setContent(&layoutFile))
       {
-        QString desktop = layoutDocument.documentElement().attribute(QLatin1String( "desktop" ));
-        KConfig c( KStandardDirs::locate("appdata", QLatin1String( "pics/" ) ) + desktop);
+        QString desktop = layoutDocument.documentElement().attribute(QStringLiteral( "desktop" ));
+        KConfig c( QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1String( "pics/" ) + desktop ) );
         KConfigGroup cg = c.group("KTuberlingTheme");
-        QString gameboard = layoutDocument.documentElement().attribute(QLatin1String( "gameboard" ));
+        QString gameboard = layoutDocument.documentElement().attribute(QStringLiteral( "gameboard" ));
         QPixmap pixmap(200,100);
         pixmap.fill(Qt::transparent);
         playGroundPixmap(gameboard,pixmap);
@@ -340,9 +350,9 @@ void PlayGround::registerPlayGrounds()
 
 void PlayGround::playGroundPixmap(const QString &playgroundName, QPixmap &pixmap)
 {
-  m_SvgRenderer.load(KStandardDirs::locate("appdata", QLatin1String( "pics/" ) + playgroundName));
+  m_SvgRenderer.load(QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1String( "pics/" ) + playgroundName ));
   QPainter painter(&pixmap);
-  m_SvgRenderer.render(&painter,QLatin1String( "background" ));
+  m_SvgRenderer.render(&painter,QStringLiteral( "background" ));
 }
 
 // Load background and draggable objects masks
@@ -366,16 +376,16 @@ bool PlayGround::loadPlayGround(const QString &gameboardFile)
 
   playGroundElement = layoutDocument.documentElement();
 
-  QString gameboardName = playGroundElement.attribute(QLatin1String( "gameboard" ));
+  QString gameboardName = playGroundElement.attribute(QStringLiteral( "gameboard" ));
 
-  QColor bgColor = QColor(playGroundElement.attribute(QLatin1String( "bgcolor" ), QLatin1String( "#fff" ) ) );
+  QColor bgColor = QColor(playGroundElement.attribute(QStringLiteral( "bgcolor" ), QStringLiteral( "#fff" ) ) );
   if (!bgColor.isValid())
     bgColor = Qt::white;
 
-  if (!m_SvgRenderer.load(KStandardDirs::locate("appdata", QLatin1String( "pics/" ) + gameboardName)))
+  if (!m_SvgRenderer.load(QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1String( "pics/" ) + gameboardName )))
     return false;
 
-  objectsList = playGroundElement.elementsByTagName(QLatin1String( "object" ));
+  objectsList = playGroundElement.elementsByTagName(QStringLiteral( "object" ));
   if (objectsList.count() < 1)
     return false;
 
@@ -401,15 +411,15 @@ bool PlayGround::loadPlayGround(const QString &gameboardFile)
   {
     objectElement = (const QDomElement &) objectsList.item(decoration).toElement();
 
-    const QString &objectName = objectElement.attribute(QLatin1String( "name" ));
+    const QString &objectName = objectElement.attribute(QStringLiteral( "name" ));
     if (m_SvgRenderer.elementExists(objectName))
     {
-      m_objectsNameSound.insert(objectName, objectElement.attribute(QLatin1String( "sound" )));
-      m_objectsNameRatio.insert(objectName, objectElement.attribute(QLatin1String( "scale" ), QLatin1String( "1" )).toDouble());
+      m_objectsNameSound.insert(objectName, objectElement.attribute(QStringLiteral( "sound" )));
+      m_objectsNameRatio.insert(objectName, objectElement.attribute(QStringLiteral( "scale" ), QStringLiteral( "1" )).toDouble());
     }
     else
     {
-      kWarning() << objectName << "does not exist. Check" << gameboardFile;
+      qWarning() << objectName << "does not exist. Check" << gameboardFile;
     }
   }
 
