@@ -15,14 +15,14 @@
 #include <stdlib.h>
 
 #include <kmessagebox.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kdebug.h>
+#include <KLocalizedString>
 
 #include <phonon/MediaObject>
 
+#include <QDir>
 #include <QDomDocument>
 #include <QFile>
+#include <QStandardPaths>
 
 #include "toplevel.h"
 
@@ -51,7 +51,7 @@ void SoundFactory::playSound(const QString &soundRef) const
 	  if (!namesList[sound].compare(soundRef)) break;
   if (sound == sounds) return;
 
-  soundFile = KStandardDirs::locate("appdata", QLatin1String( "sounds/" ) + filesList[sound]);
+  soundFile = QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1String( "sounds/" ) + filesList[sound]);
   if (soundFile.isEmpty()) return;
 
 //printf("%s\n", (const char *) soundFile);
@@ -62,7 +62,16 @@ void SoundFactory::playSound(const QString &soundRef) const
 // Register the various languages
 void SoundFactory::registerLanguages()
 {
-  const QStringList list = KGlobal::dirs()->findAllResources("appdata", QLatin1String( "sounds/*.soundtheme" ));
+  QSet<QString> list;
+  const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("sounds"), QStandardPaths::LocateDirectory);
+  Q_FOREACH (const QString &dir, dirs)
+  {
+    const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.soundtheme"));
+    Q_FOREACH (const QString &file, fileNames)
+    {
+        list <<dir + '/' + file;
+    }
+  }
 
   foreach(const QString &soundTheme, list)
   {
@@ -72,8 +81,8 @@ void SoundFactory::registerLanguages()
       QDomDocument document;
       if (document.setContent(&file))
       {
-        QString code = document.documentElement().attribute(QLatin1String( "code" ));
-        bool enabled = !(KStandardDirs::locate("appdata", QLatin1String( "sounds/" ) + code + QLatin1Char( '/' )).isEmpty());
+        QString code = document.documentElement().attribute(QStringLiteral( "code" ));
+        bool enabled = !(QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1String( "sounds/" ) + code + QLatin1Char( '/' ), QStandardPaths::LocateDirectory).isEmpty());
         topLevel->registerLanguage(code, soundTheme, enabled);
       }
     }
@@ -97,7 +106,7 @@ bool SoundFactory::loadLanguage(const QString &selectedLanguageFile)
 
   languageElement = document.documentElement();
 
-  soundNamesList = languageElement.elementsByTagName(QLatin1String( "sound" ));
+  soundNamesList = languageElement.elementsByTagName(QStringLiteral( "sound" ));
   sounds = soundNamesList.count();
   if (sounds < 1)
     return false;
@@ -109,9 +118,9 @@ bool SoundFactory::loadLanguage(const QString &selectedLanguageFile)
   {
     soundNameElement = (const QDomElement &) soundNamesList.item(sound).toElement();
 
-    nameAttribute = soundNameElement.attributeNode(QLatin1String( "name" ));
+    nameAttribute = soundNameElement.attributeNode(QStringLiteral( "name" ));
     namesList << nameAttribute.value();
-    fileAttribute = soundNameElement.attributeNode(QLatin1String( "file" ));
+    fileAttribute = soundNameElement.attributeNode(QStringLiteral( "file" ));
     filesList << fileAttribute.value();
   }
 
